# -*- coding: utf-8 -*-
import xbmcplugin, xbmcgui, xbmcaddon, xbmc, traceback
import os, sys, urllib, re, math

if sys.version_info >= (2,7): import json as _json
else: import simplejson as _json 

scriptID = sys.modules[ "__main__" ].scriptID
scriptname   = sys.modules[ "__main__" ].scriptname
ptv = xbmcaddon.Addon(scriptID)

SERVICE = 'ninateka'

BASE_IMAGE_PATH = 'http://sd-xbmc.org/repository/xbmc-addons/'
BASE_RESOURCE_PATH = os.path.join( ptv.getAddonInfo('path'), "../resources" )
sys.path.append( os.path.join( BASE_RESOURCE_PATH, "lib" ) )

import sdLog, sdParser, sdCommon, sdNavigation, sdErrors

LOGOURL = BASE_IMAGE_PATH + "ninateka.png"
THUMB_NEXT = BASE_IMAGE_PATH + 'dalej.png'

log = sdLog.pLog()

dstpath = ptv.getSetting('default_dstpath')
dbg = sys.modules[ "__main__" ].dbg

USER_AGENT = 'Apache-HttpClient/UNAVAILABLE (java 1.4)'
#MAIN http://www.nina.gov.pl/components/services/ninatekaAPI.ashx?listType=recommended

INITIAL_LIST_URL = 'http://samsungapi.ninateka.pl/catalog/getresult?listType=recommended'

#INITIAL_LIST_URL = 'http://localhost:8080/ninatekamain.json'
NINATLO= 'http://nina.files.e54-po.insyscd.net/tlo-na-strone-glowna-ninateki/tlo-zolte2.jpg'

API = 'http://samsungapi.ninateka.pl/catalog/getresult?'

nina_url_keys = ("service","name","mediaPath")


MAIN_MENU = {
    1: "Kategorie Video",
    2: "Kategorie Audio"
}


class Ninateka:
	def __init__(self):
		log.info('Loading ' + SERVICE)
		self.cm = sdCommon.common()
		self.parser = sdParser.Parser()
		self.exception = sdErrors.Exception()
		self.gui = sdNavigation.sdGUI()
		self.jsonAll = None 

	def loadJson(self, url):
		try:
                        result = self.cm.getURLRequestData({ 'url': url, 'use_host': False, 'use_cookie': False, 'use_post': False, 'return_data': True })
                        self.jsonAll = _json.loads(result)
		except Exception, exception:
                        traceback.print_exc()
                        self.exception.getError(str(exception))
                        exit()

	def listMainMenu(self, table):
		for num, val in table.items():
		    params = {'service': SERVICE, 'name': 'main-menu', 'title': val, 'icon': LOGOURL, 'fanart': NINATLO}
		    self.gui.addDir(params)
		self.gui.endDir()
	
	def listSubMenu(self, title, url):
		self.loadJson(url)
		if title == MAIN_MENU[1]:
                        json_key = 'video_categories'
                elif title == MAIN_MENU[2]:
                        json_key = 'audio_categories'
                for item in self.jsonAll[json_key]:
                        t = self.getJItemStr( item , 'name')
                        api_url = self.getJItemStr( item , 'api_url')
                        # http://samsungapi.ninateka.pl/catalog/getResult?listtype=media_list&mediaType=audio-video&categoryId=poezja
                        pattern = '^http(.+?)mediaType=(.+?)&categoryId=(.+?)$' 
                        r = re.compile(pattern).findall(api_url)    
			params = {'service': SERVICE, 'name': 'sub-menu', 'title': t, 'mediaType': r[0][1],'categoryId': r[0][2],'icon': LOGOURL, 'fanart': NINATLO}
			self.gui.addDir(params)
		self.gui.endDir()

	def listCategory(self, title, mediaType, categoryId):
                sort = True
                url = API + 'listtype=media_list&mediaType=' + mediaType + '&categoryId=' + categoryId
		self.loadJson(url)

                if mediaType == 'audio-video':
                        json_key = 'video_list'
                elif mediaType == 'audio':
                        json_key = 'audio_list'
                
                for item in self.jsonAll[json_key]:
                        title = self.getJItemStr( item , 'name')
                        # http://nina.files.rd.insyscd.net/okladki/mikrologia.png?m=resize&w=100&h=75
			icon = self.getJItemStr( item , 'thumbnails').split('?')[0]
                        duration = self.getJItemStr( item , 'time')
                        log.info("AA "+duration)
                        min = re.split('\'|\"',duration)[0]
                        sec = re.split('\'|\"',duration)[1]
                        d = str(60*int(min)+int(sec))
                        plot = self.getJItemStr( item , 'lead')
                        url = self.getJItemStr( item , 'url')
                        #http://samsungapi.ninateka.pl/catalog/getresult?listType=details&mediaPath=kon-a-sprawa-polska-krzysztof-debowski&cat=animacje
                        pattern = '^http(.+?)mediaPath=(.+?)&cat=(.+?)$' 
                        r = re.compile(pattern).findall(url)
                        params = {'service': SERVICE, 'name': mediaType, 'title': title , 'mediaPath': r[0][1], 'icon': icon,'duration':d, 'fanart': icon,'plot':plot}
                        self.gui.playVideo(params,isPlayable = True,params_keys_needed = nina_url_keys)
		self.gui.endDir(sort)

                
	def getJItemStr(self, item, key, default=''):
		v = item.get(key, None)
		if None == v:
			return default
		return v.encode('utf-8')

	def getAudioVideoLink(self, mediaPath):
		url = API + 'listType=details&mediaPath=' + mediaPath
                self.loadJson(url)
                audioVideoUrl = ""
                if 'video_list' in self.jsonAll :
                        videoUrl = self.jsonAll['video_list'][0]['movie']
                if 'audio_list' in self.jsonAll :
                        videoUrl = self.jsonAll['audio_list'][0]['movie']     
		return videoUrl


	def handleService(self):
		params = self.parser.getParams()
                service = self.parser.getParam(params, "service")
		name = self.parser.getParam(params, "name")
		title = self.parser.getParam(params, "title")
		icon = self.parser.getParam(params, "icon")


		self.parser.debugParams(params, dbg)

                #MAIN MENU
		if name == None:
			self.listMainMenu(MAIN_MENU)
                # Audio albo Video        
		elif name == 'main-menu':  
			log.info(title)
			self.listSubMenu(title,INITIAL_LIST_URL)
                elif name == 'sub-menu':  # Audio albo Video
			log.info(title)
                        mediaType = self.parser.getParam(params, "mediaType")
                        categoryId = self.parser.getParam(params, "categoryId")
			self.listCategory(title,mediaType,categoryId)
		#ODTWÓRZ VIDEO / AUDIO
		elif name == 'playSelectedVideo':
                        mediaPath = self.parser.getParam(params, "mediaPath")
			videoUrl = self.getAudioVideoLink(mediaPath)
			self.gui.LOAD_AND_PLAY_VIDEO_WATCHED(videoUrl)
               